@@ -1,4 +1,4 @@
-from pydantic import BaseModel, Field
+from pydantic import BaseModel, Field, ConfigDict
 from typing import Optional, List
 
 from fairscape_models.fairscape_base import IdentifierValue, IdentifierPropertyValue
@@ -14,4 +14,7 @@ class BioChemEntity(BaseModel):
     identifier: Optional[List[IdentifierPropertyValue]] = Field(default=[])
     associatedDisease: Optional[IdentifierValue] = Field(default=None)
     usedBy: Optional[List[IdentifierValue]] = Field(default=[])
-    description: Optional[str] = Field(default=None)
\ No newline at end of file
+    description: Optional[str] = Field(default=None)
+    isPartOf: Optional[List[IdentifierValue]] = Field(default=[])
+    
+    model_config = ConfigDict(extra="allow")
\ No newline at end of file
