@@ -6,7 +6,7 @@ from fairscape_models.fairscape_base import IdentifierValue, DATASET_TYPE
 class Dataset(BaseModel):
     guid: str = Field(alias="@id")
     name: str
-    metadataType: Optional[str] = Field(default="https://w3id.org/EVI#Dataset")
+    metadataType: Optional[str] = Field(default="https://w3id.org/EVI#Dataset",alias="@type")
     additionalType: Optional[str] = Field(default=DATASET_TYPE)
     author: Union[str, List[str]]
     datePublished: str = Field(...)
@@ -25,12 +25,6 @@ class Dataset(BaseModel):
     derivedFrom: Optional[List[IdentifierValue]] = Field(default=[])
     usedByComputation: Optional[List[IdentifierValue]] = Field(default=[])
     contentUrl: Optional[Union[str, List[str]]] = Field(default=None)
+    isPartOf: Optional[List[IdentifierValue]] = Field(default=[])
 
-    model_config = ConfigDict(extra="allow")
-    
-    @field_validator('dataSchema', mode='before')
-    @classmethod
-    def validate_data_schema(cls, v):
-        if v == '' or v is None:
-            return None
-        return v
\ No newline at end of file
+    model_config = ConfigDict(extra="allow")
\ No newline at end of file
